@@ -1,7 +1,8 @@
 
 .onAttach <- function(libname, pkgname) {
     packageStartupMessage("The littler package provides 'r' as a binary.")
-    packageStartupMessage("See 'vignette(\"littler-examples\") for some illustrations.")
+    packageStartupMessage("See 'vignette(\"littler-examples\") for several usage illustrations,")
+    packageStartupMessage("and see 'vignette(\"littler-faq\") for some basic questions.")
     if (Sys.info()[["sysname"]] == "Linux") {
         if (unname(Sys.which("r")) == "") { # nocov start
             packageStartupMessage("You could link to the 'r' binary installed in\n'",
